/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    Timon Veenstra <monezz@gmail.com> - initial API and implementation and/or initial documentation
 */
package eu.agrosense.client.grid;

/**
 * Describes capability of converting one or more source grids into a new
 * grid. For example a SensorExtrapolationConverter could extrapolate sensor
 * data in a source raster and make sure all empty fields are filled with a value.
 * 
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
public interface GridOperation {
    
    
    
    /**
     * Returns localized string with the name of the converter.
     * Save to display in the gui
     * 
     * @return localized String with the name of the converter
     */
    String getDisplayName();
    
    
    /**
     * Localized string with a description what the converter does.
     * Should also provide information about the order of the grids if important.
     * 
     * @return 
     */
    String getDescription();
    

    
    /**
     * execute the current operation.
     * 
     * @param grids single grid operation execution
     * @return 
     */
    void execute(CalculationGrid grid);
    

    
}
