/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    johan - initial API and implementation and/or initial documentation
 */
package eu.agrosense.client.grid.util;

/**
 *
 * @author johan
 */
public class TransformationStrategies {
     
    /**
     * Default implementation which uses values as is.
     * @param <C> 
     */
    public static class Noop<C extends TransformationContext> implements TransformationStrategy<C> {

        @Override
        public Double transformIn(double value, TransformationContext context) {
            return value;
        }

        @Override
        public Double transformOut(AggregationStrategy agg) {
            return agg.getAggregate();
        }
    }
    
    /**
     * Makes raster details available in the global transformation context.
     * (i.e. on all transformation calls)
     * 
     * @param <C> 
     */
    public static abstract class WithRasterContext<C extends TransformationContext> implements TransformationStrategy<C> {
        private final RasterHelper rasterHelper;

        public WithRasterContext(RasterHelper rasterHelper) {
            this.rasterHelper = rasterHelper;
        }

        public RasterHelper getRasterHelper() {
            return rasterHelper;
        }

    }

}
